==> hadoop-apache2-2.7.4-9-sources.jar: com/facebook/presto/hadoop/$internal/org/apache/http/impl/io/HttpResponseWriter.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package com.facebook.presto.hadoop.$internal.org.apache.http.impl.io;

import java.io.IOException;

import com.facebook.presto.hadoop.$internal.org.apache.http.HttpResponse;
import com.facebook.presto.hadoop.$internal.org.apache.http.annotation.NotThreadSafe;
import com.facebook.presto.hadoop.$internal.org.apache.http.io.SessionOutputBuffer;
import com.facebook.presto.hadoop.$internal.org.apache.http.message.LineFormatter;
import com.facebook.presto.hadoop.$internal.org.apache.http.params.HttpParams;

/**
 * HTTP response writer that serializes its output to an instance
 * of {@link SessionOutputBuffer}.
 *
 * @since 4.0
 */
@NotThreadSafe
public class HttpResponseWriter extends AbstractMessageWriter<HttpResponse> {

    public HttpResponseWriter(final SessionOutputBuffer buffer,
                              final LineFormatter formatter,
                              final HttpParams params) {
        super(buffer, formatter, params);
    }

    @Override
    protected void writeHeadLine(final HttpResponse message) throws IOException {
        lineFormatter.formatStatusLine(this.lineBuf, message.getStatusLine());
        this.sessionBuffer.writeLine(this.lineBuf);
    }

}

==> hadoop-apache-3.4.1-1-sources.jar: com/facebook/presto/hadoop/$internal/org/apache/http/impl/io/HttpResponseWriter.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package com.facebook.presto.hadoop.\$internal.org.apache.http.impl.io;

import java.io.IOException;

import com.facebook.presto.hadoop.\$internal.org.apache.http.HttpResponse;
import com.facebook.presto.hadoop.\$internal.org.apache.http.io.SessionOutputBuffer;
import com.facebook.presto.hadoop.\$internal.org.apache.http.message.LineFormatter;
import com.facebook.presto.hadoop.\$internal.org.apache.http.params.HttpParams;

/**
 * HTTP response writer that serializes its output to an instance
 * of {@link SessionOutputBuffer}.
 *
 * @since 4.0
 *
 * @deprecated (4.3) use {@link DefaultHttpResponseWriter}
 */
@Deprecated
public class HttpResponseWriter extends AbstractMessageWriter<HttpResponse> {

    public HttpResponseWriter(final SessionOutputBuffer buffer,
                              final LineFormatter formatter,
                              final HttpParams params) {
        super(buffer, formatter, params);
    }

    @Override
    protected void writeHeadLine(final HttpResponse message) throws IOException {
        lineFormatter.formatStatusLine(this.lineBuf, message.getStatusLine());
        this.sessionBuffer.writeLine(this.lineBuf);
    }

}
